Rietveld Code Review Tool
Help | Bug tracker | Discussion group | Source code | Sign in
(92)

Unified Diff: test/fixedbugs/bug392.dir/pkg3.go

Issue 6443110: code review 6443110: test: use run.go for more tests. (Closed)
Patch Set: diff -r ca5e20f93081 https://go.googlecode.com/hg/ Created 12 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Please Sign in to add in-line comments.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « test/fixedbugs/bug392.dir/pkg2.go ('k') | test/fixedbugs/bug415.go » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: test/fixedbugs/bug392.dir/pkg3.go
===================================================================
rename from test/fixedbugs/bug392.dir/three.go
rename to test/fixedbugs/bug392.dir/pkg3.go
--- a/test/fixedbugs/bug392.dir/three.go
+++ b/test/fixedbugs/bug392.dir/pkg3.go
@@ -2,12 +2,12 @@
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.
// Use the functions in one.go so that the inlined
// forms get type-checked.
-package three
+package pkg3
-import "./two"
+import "./pkg2"
-var x = two.F()
-var v = two.V
+var x = pkg2.F()
+var v = pkg2.V
« no previous file with comments | « test/fixedbugs/bug392.dir/pkg2.go ('k') | test/fixedbugs/bug415.go » ('j') | no next file with comments »

Powered by Google App Engine
@@ -2,12 +2,12 @@
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.
-// Use the functions in one.go so that the inlined
+// Use the functions in pkg2.go so that the inlined
// forms get type-checked.
RSS Feeds Recent Issues | This issue
This is Rietveld f62528b